// The Vue build version to load with the `import` command
// (runtime-only or standalone) has been set in webpack.base.conf with an alias.
import Vue from 'vue';
import App from './App';
import router from './router';
import store from './store';
import ElementUI from 'element-ui';
import 'element-ui/lib/theme-chalk/index.css';
// import 'assets/custom-theme/index.css'; // 换肤版本element-ui css
import NProgress from 'nprogress'; // Progress 进度条
import 'nprogress/nprogress.css'; // Progress 进度条 样式
import 'normalize.css/normalize.css'; // normalize.css 样式格式化
import 'assets/iconfont/iconfont.css';
import * as filters from './filters'; // 全局vue filter
import Multiselect from 'vue-multiselect'; // 使用的一个多选框组件，element-ui的select不能满足所有需求
import 'vue-multiselect/dist/vue-multiselect.min.css'; // 多选框组件css
import Sticky from 'components/Sticky'; // 粘性header组件
import IconSvg from 'components/Icon-svg'; // svg 组件
import vueWaves from './directive/waves'; // 水波纹指令
import errLog from 'store/errLog'; // error log组件
import { getToken } from 'utils/auth';
import { Popover } from 'element-ui';
import 'babel-polyfill'
// register globally
Vue.use(ElementUI);

Vue.component('multiselect', Multiselect);
Vue.component('Sticky', Sticky);
Vue.component('icon-svg', IconSvg)

Vue.use(vueWaves);
Vue.use(Popover);
// register global utility filters.
Object.keys(filters).forEach(key => {
	Vue.filter(key, filters[key])
});

//视频
import "videojs-contrib-hls";
// Vue.use(jQuery);
import VueVideoPlayer from 'vue-video-player'
import 'video.js/dist/video-js.css'

require('video.js/dist/video-js.css')
require('vue-video-player/src/custom-theme.css')
// Vue.use(VueVideoPlayer)


// register global progress.
const whiteList = ['/login', '/authredirect']; // 不重定向白名单

router.beforeEach((to, from, next) => {
	NProgress.start();
	let token = localStorage.getItem('token');
	if (token) { // 判断是否有token
		if (to.path === '/login') {
			next();
		} else {
			next();
			//			if(store.getters.menus !== undefined) { // 判断当前用户是否已拉取完user_info信息
			//				store.dispatch('GetInfo').then(info => { // 拉取user_info
			//					const menus = {};
			//					for(let i = 0; i < info.menus.length; i++) {
			//						menus[info.menus[i].code] = true;
			//					}
			//					/*store.dispatch('GenerateRoutes', menus).then(() => { // 生成可访问的路由表
			//						router.addRoutes(store.getters.addRouters) // 动态添加可访问路由表
			//						next({ ...to
			//						}); // hack方法 确保addRoutes已完成
			//					})*/
			//				}).catch(() => {
			//					store.dispatch('FedLogOut').then(() => {
			//						next({
			//							path: '/login'
			//						});
			//					})
			//				})
			//			} else {
			//				next();
			//			}
		}
	} else {
		if (whiteList.indexOf(to.path) !== -1) { // 在免登录白名单，直接进入
			next()
		} else {
			//next();
			next('/login'); // 否则全部重定向到登录页
			NProgress.done(); // 在hash模式下 改变手动改变hash 重定向回来 不会触发afterEach 暂时hack方案 ps：history模式下无问题，可删除该行！
		}
	}
});

router.afterEach(() => {
	NProgress.done(); // 结束Progress
});

Vue.config.productionTip = false;

// 生产环境错误日志
if (process.env.NODE_ENV === 'production') {
	Vue.config.errorHandler = function (err, vm) {
		console.log(err, window.location.href);
		errLog.pushLog({
			err,
			url: window.location.href,
			vm
		})
	};
}

new Vue({
	el: '#app',
	router,
	store,
	template: '<App/>',
	components: {
		App
	}
})

