import Vue from 'vue';
import Router from 'vue-router';
const _import = require('./_import_' + process.env.NODE_ENV);

Vue.use(Router);

import Layout from '../views/layout/Layout';

export const constantRouterMap = [
    {
        path: '/',
        redirect: '/login',
        hidden: true
    },
    {
        path: '/login',
        component: _import('login/index'),
        hidden: true
    },
    {
        path: '/404',
        component: _import('error/404'),
        hidden: true
    },
    //微信登录接口
    {
        path: '/weixin',
        component: _import('weixin/index'),
        hidden: true
    },
    //短信登录接口
    {
        path: '/mlogin',
        component: _import('mlogin/index'),
        hidden: true
    },
    {
        path: '/authredirect',
        component: _import('login/authredirect'),
        hidden: true
    },
    {
        path: '/test',
        component: _import('test/index'),
        hidden: true
    },

    {
        path: '/userCenter',
        component: Layout,
        redirect: '/userManager/userManagerHome',
        name: '用户中心',
        meta: {
            title: '用户中心',
            icon: 'icon-wodeyingyong'
        },
        children: [
            {
                path: '/organizationManager',
                component: {
                    render(c) {
                        return c('router-view')
                    }
                },
                name: '机构管理',
                //authority: 'userManager',
                meta: {
                    title: '机构管理',
                    icon: ' icon-yonghu'
                },
                hidden: false,
                children: [{
                    path: 'organization',
                    component: _import('admin/organization/organization/index'),
                    name: '组织管理',
                    meta: {
                        title: '组织管理',
                        icon: 'icon-dian'
                    },
                },
                {
                    path: 'deptManager',
                    component: _import('admin/organization/deptManager/index'),
                    name: '部门管理',
                    meta: {
                        title: '部门管理',
                        icon: 'icon-dian'
                    },
                }
                ]
            },
            {
                path: 'characterManager',
                component: _import('admin/roleManage/index'),
                name: '角色管理',
                //authority: 'userManager',
                meta: {
                    title: '角色管理',
                    icon: ' icon-yonghu'
                },
                hidden: false
            },
            {
                path: '/para',
                component: {
                    render(c) {
                        return c('router-view')
                    }
                },
                name: '参数管理',
                //authority: 'userManager',
                hidden: false,
                meta: {
                    title: '参数管理',
                    icon: ''
                },
                children: [{
                    path: 'para',
                    component: _import('admin/para/index'),
                    name: '参数类型',
                    meta: {
                        title: '参数类型',
                        icon: 'icon-dian'
                    },
                }, {
                    path: 'paraConfig',
                    component: _import('admin/para/config/index'),
                    name: '参数信息',
                    meta: {
                        title: '参数信息',
                        icon: 'icon-dian'
                    },
                }]
            },
            {
                path: '/resourceManager',
                component: {
                    render(c) {
                        return c('router-view')
                    }
                },
                name: '资源管理',
                //authority: 'userManager',
                meta: {
                    title: '资源管理',
                    icon: ' icon-yonghu'
                },
                hidden: false,
                children: [{
                    path: 'pageResources',
                    component: _import('admin/resourceManage/pageResource/index'),
                    name: '页面资源',
                    meta: {
                        title: '页面资源',
                        icon: ''
                    }
                }]
            },
            {
                path: '/userManager',
                component: {
                    render(c) {
                        return c('router-view')
                    }
                },
                name: '用户管理',
                meta: {
                    title: '用户管理',
                    icon: ' icon-yonghu'
                },
                hidden: false,
                children: [{
                    path: 'userManagerHome',
                    component: _import('admin/userManager/index'),
                    name: '用户管理',
                    meta: {
                        title: '用户管理',
                        icon: 'icon-yonghu'
                    }
                }]

            },
            {
                path: '/dataDict',
                component: {
                    render(c) {
                        return c('router-view')
                    }
                },
                name: '数据字典',
                //authority: 'userManager',
                meta: {
                    title: '数据字典',
                    icon: ' icon-yonghu'
                },
                hidden: false,
                children: [{
                    path: 'group',
                    component: _import('dictData/dictGroup'),
                    name: '字典组',
                    meta: {
                        title: '字典组',
                        icon: 'icon-dian'
                    },
                }, {
                    path: 'dict',
                    component: _import('dictData/dict'),
                    name: '字典',
                    meta: {
                        title: '字典',
                        icon: 'icon-dian'
                    },
                }]
            },
            // {
            //     path: '/videoDictionaries',
            //     component: {
            //         render(c) {
            //             return c('router-view')
            //         }
            //     },
            //     name: '视频监控字典',
            //     hidden: true,
            //     //authority: 'userManager',
            //     meta: {
            //         title: '视频监控字典',
            //         icon: ' icon-yonghu'
            //     },
            //     children: [{
            //         path: 'group',
            //         component: _import('videoDictionaries/videoDictionaries'),
            //         name: '视频监控字典',
            //         meta: {
            //             title: '视频监控字典',
            //             icon: 'icon-dian'
            //         }
            //     },
            //     ]
            // },
            {//日志管理
                path: '/logManager',
                component: {
                    render(c) {
                        return c('router-view')
                    }
                },
                name: '日志管理',
                meta: {
                    title: '日志管理',
                    icon: ' icon-yonghu'
                },
                hidden: false,
                children: [{
                    path: 'logAudit',
                    component: _import('admin/logManager/logAudit/index'),
                    name: '审计日志',
                    meta: {
                        title: '审计日志',
                        icon: 'icon-dian'
                    },
                }, {
                    path: 'logPageEnter',
                    component: _import('admin/logManager/logPageEnter/index'),
                    name: '页面访问日志',
                    meta: {
                        title: '页面访问日志',
                        icon: 'icon-dian'
                    },
                }, {
                    path: 'loginSysLogin',
                    component: _import('admin/logManager/loginSysLogin/index'),
                    name: '系统登录日志',
                    meta: {
                        title: '系统登录日志',
                        icon: 'icon-dian'
                    }
                }]
            }
        ]
    }, {
        path: '*',
        redirect: '/404',
        hidden: true
    }

]

export default new Router({
    //mode: 'history', //后端支持可开
    routes: constantRouterMap
});
