import {
	loginByEmail,
	logout,
	getMenus,
	getInfo,
	getRightsAllocation,
	sendMessage,
	messLogin
} from 'api/login';
import {
	getToken,
	setToken,
	removeToken,
	getPhoto,
	setPhoto,
	removePhoto,
	getUserId,
	setUserId,
	removeUserId,
	getUserName,
	setUserName,
	removeUserName,
	getUdepId,
	setUdepId,
	removeUdepId,
	getUdepPid,
	setUdepPid,
	removeUdepPid,
	getRange,
	setRange,
	removeRange
} from 'utils/auth';
import md5 from 'js-md5';
/*1.创建state仓库*/
const user = {
	state: {
		user: 'user',
		userId: sessionStorage.getItem('userId'),
		status: '',
		code: '',
		token: getToken(),
		photo: getPhoto(),
		name: '',
		avatar: '',
		roles: [],
		menus: undefined,
		eleemnts: undefined,
		permissionMenus: undefined,
		//角色管理数据
		dataSource: [],
		//已选角色管理数据
		checkedIds: [],
		checkedLabels: [],
		pageResourceData: [], //页面资源
		dataResourceData: [], //数据资源
		approveData: [], //审批资源
		setting: {
			articlePlatform: []
		}
	},
	/*2.在mutations里面定义state里面每个属性的修改方法*/
	mutations: {
		SET_USERID: (state, userId) => {
			state.userId = userId;
		},
		SET_PHOTO: (state, photo) => {
			state.photo = photo
		},
		SET_CODE: (state, code) => {
			state.code = '';
		},
		SET_TOKEN: (state, token) => {
			state.token = token;
		},
		SET_SETTING: (state, setting) => {
			state.setting = setting;
		},
		SET_STATUS: (state, status) => {
			state.status = status;
		},
		SET_NAME: (state, name) => {
			state.name = name;
		},
		SET_AVATAR: (state, avatar) => {
			state.avatar = avatar;
		},
		SET_ROLES: (state, roles) => {
			state.roles = roles;
		},
		SET_MENUS: (state, menus) => {
			state.menus = menus;
		},
		SET_ELEMENTS: (state, elements) => {
			state.elements = elements;
		},
		LOGIN_SUCCESS: () => {
			console.log('login success')
		},
		LOGOUT_USER: state => {
			state.user = '';
		},
		SET_PERMISSION_MENUS: (state, permissionMenus) => {
			state.permissionMenus = permissionMenus;
		}
	},
	/*3.在actions里面可以调用mutations里面的方法，并且可以自定义方法，在外面的组件内通过dispatch来调用*/
	actions: {
		//天津
		Login({
			commit
		}, userInfo) {
			const name = userInfo.name.trim()
			const pwd = md5(userInfo.password)
			return new Promise((resolve, reject) => {
				loginByEmail(name, pwd).then(response => {
					if (response.infoCode == 200) {
						const data = response.data
						// setToken(data.token)
						// commit('SET_NAME', data.lsUser.name)
						// setUserId(data.lsUser.id)
						localStorage.setItem('token', data.token)
						sessionStorage.setItem('TOKENL', data.token)
						commit('SET_TOKEN', data.token)
						resolve(response)
					}
					resolve(response)
				}).catch(error => {
					reject(error)
				})
			})
		},


		// 用户登录
		LoginByEmail({
			commit
		}, userInfo) {
			const name = userInfo.name.trim();
			// commit('SET_TOKEN', '');
			// commit('SET_ROLES', []);
			// commit('SET_USERID', '');
			// commit('SET_MENUS', undefined);
			// commit('SET_ELEMENTS', undefined);
			removeToken();
			return new Promise((resolve, reject) => {
				loginByEmail(name, userInfo.password).then(response => {
					console.log(response, 'login')
					if (response.infoCode == 200) {

						localStorage.setItem('token', response.data.token)
						sessionStorage.setItem('token', response.data.token)
						//获取用户信息
						getInfo(response.data.toke).then(response => {
							console.log(response, 'login')
							if (response.infoCode == 200) {
								localStorage.setItem('orgCode', response.data.orgCode)
								sessionStorage.setItem('orgCode', response.data.orgCode)
								localStorage.setItem('orgName', response.data.orgName)
								sessionStorage.setItem('orgName', response.data.orgName)
								//获取角色拥有菜单
								let userRole = response.data.userRole.join(",")

								localStorage.setItem('userRole', userRole)
								sessionStorage.setItem('userRole', userRole)
								resolve(response);
							} else {
								reject(response)
							}
						}).catch(error => {
							reject(error);
						});

						resolve(response);
					} else {
						reject(response)
					}
				}).catch(error => {
					reject(error);
				});
			});
		},

		// 登出
		LogOut({
			commit,
			state
		}) {
			return new Promise((resolve, reject) => {
				logout(state.token).then(() => {
					commit('SET_TOKEN', '');
					commit('SET_ROLES', []);
					commit('SET_MENUS', undefined);
					commit('SET_ELEMENTS', undefined);
					commit('SET_PERMISSION_MENUS', undefined);
					removeToken();
					removePhoto();
					resolve();
				}).catch(error => {
					reject(error);
				});
			});
		},

		// 前端 登出
		FedLogOut({
			commit
		}) {
			return new Promise(resolve => {
				commit('SET_TOKEN', '');
				commit('SET_MENUS', undefined);
				commit('SET_ELEMENTS', undefined);
				commit('SET_PERMISSION_MENUS', undefined);
				localStorage.clear();
				removeToken();
				removePhoto();
				sessionStorage.removeItem("userId")
				resolve();
			});
		},
		SendMess({
			commit
		}, mobile) {
			//			removeToken();
			return new Promise((resolve, reject) => {
				sendMessage(mobile).then(response => {
					console.log(response, 'sendMess')
					if (response.infoCode == 200) {

						resolve(response);
					} else {
						reject(response)
					}
				}).catch(error => {
					reject(error);
				});
			});
		},
		MessLogin({
			commit
		}, userInfo) {
			//			removeToken();
			return new Promise((resolve, reject) => {
				messLogin(userInfo.mobile, userInfo.code).then(response => {
					console.log(response, 'messLogin')
					if (response.infoCode == 200) {
						resolve(response);
					} else {
						reject(response)
					}
				}).catch(error => {
					reject(error);
				});
			});
		}
	}
};

export default user;
