import axios from 'axios';
import {
	Message,
	MessageBox
} from 'element-ui';
import store from '../store';
import {
	getToken
} from 'utils/auth';

// 创建axios实例
const service = axios.create({
	headers: {
		'Content-Type': 'application/json;charset=utf-8',
		'Cache-Control': 'no-cache',
    	'Pragma': 'no-cache'
	},
	baseURL: process.env.BASE_API, // api的base_url
});

if(!window.flag){
	service.interceptors.request.use(config => {
		// Do something before request is sent
		let token = localStorage.getItem('token');
		if (token) {
			config.headers['token'] = token; // 让每个请求携带token--['X-Token']为自定义key 请根据实际情况自行修改
		}
		return config;
	}, error => {
		// Do something with request error
		console.log(error); // for debug
		Promise.reject(error);
	})
}


axios.defaults.withCredentials = true; //设置让每个请求携带cookie

// respone拦截器
service.interceptors.response.use(
	response => {
		/**
		 * 下面的注释为通过response自定义code来标示请求状态，当code返回如下情况为权限有问题，登出并返回到登录页
		 * 如通过xmlhttprequest 状态码标识 逻辑可写在下面error中
		 */
		let token = window.localStorage.getItem('token');
		if(response.headers.token){
			window.flag = true;
			window.localStorage.setItem("token",response.headers.token);
			//setToken(response.headers.token)
			window.flag = false;
		}
		const res = response.data;
		// && res.status !== 200
		if(response.status !== 200) {
			Message({
				message: res.msg,
				type: 'error',
				duration: 1000
			});
		} else {
			if(response.headers.token){
				window.flag = true;
				localStorage.removeItem('token')
				localStorage.setItem("token",response.headers.token);
				setToken(response.headers.token)
				window.flag = false;
			}
			return response.data;
		}
	},
	error => {
		let code=error.message.substr(error.message.length-3)
		if(code==='401'){
			MessageBox.confirm('你已被登出，可以取消继续留在该页面，或者重新登录', '确定登出', {
				confirmButtonText: '重新登录',
				cancelButtonText: '取消',
				type: 'warning'
			}).then(() => {
				store.dispatch('FedLogOut').then(() => {
					location.reload(); // 为了重新实例化vue-router对象 避免bug
					// window.location.href="http://baidu.com"
				});
			})
			return Promise.reject('error');
		}else{
			Message({
				message: error.message,
				type: 'error',
				duration: 1000
			});	
		}
		return Promise.reject(error);
	}
);

export default service;
